Installation — Lagranto 0.1 documentation

# Installation

## Using conda

conda install -c conda-forge lagranto

## Using pip

Ideally install it in a virtual environment. See for example virtualenvwrapper.

    pip install Lagranto

Then you can install the dependencies for testing or the documentations as follow:

    pip install Lagranto[testing]
    pip install Lagranto[docs]

To build the documentation do the following:

    cd /path/to/lagranto/location
    cd docs
    make html

To test the package do the following:

    cd /path/to/lagranto/location
    pytest